# History

## 0.2.1 (2018-10-20)

-   Switch to using python-decouple for env var management

## 0.2.0 (2018-10-20)

-   Switch to using python-decouple for env var management

## 0.1.7 (2018-10-12)

-   Variable naming correction

## 0.1.6 (2018-10-12)

-   Address settings namespace issue

## 0.1.5 (2018-10-12)

-   Correction of arguments

## 0.1.4 (2018-10-12)

-   Add legacy `run_migration` argument

## 0.1.3 (2018-10-12)

-   Corrected import path

## 0.1.2 (2018-10-12)

-   First pass at working functionality

## 0.1.1 (2018-10-12)

-   Second release on PyPI.

## 0.1.0 (2018-10-12)

-   First release on PyPI.
